@@ -17,7 +17,7 @@
  * Boston, MA 02111-1307, USA.
  */
 
-/* $Id: mcrypt.c,v 1.4 2000/10/25 18:43:11 nmav Exp $ */
+/* $Id: mcrypt.c,v 1.11 2001/02/01 10:34:51 nmav Exp $ */
 
 /* Changed by Steve Underwood 1999/12/10 to allow an arbitrary number of 
  * streams of encryption. Currently the resulting code is probably not
@@ -36,6 +36,8 @@
  *						--nikos
  */
 
+/* The above comments are too old! */
+
 #ifndef LIBDEFS_H
 #define LIBDEFS_H
 #include <libdefs.h>
@@ -54,10 +56,12 @@ static int internal_init_mcrypt(MCRYPT td, void *key, int lenofkey, void *IV)
 {
 	int *sizes = NULL;
 	int num_of_sizes, i, ok = 0;
-	if (lenofkey == 0) {
-		return MCRYPT_KEY_LEN_ERROR;	/* error */
-	}
+	int key_size = mcrypt_enc_get_key_size(td);
 
+	if (lenofkey > key_size || lenofkey==0) {
+		return MCRYPT_KEY_LEN_ERROR;	/* error */	
+	}
+	
 	sizes = mcrypt_enc_get_supported_key_sizes(td, &num_of_sizes);
 	if (sizes != NULL) {
 		for (i = 0; i < num_of_sizes; i++) {
@@ -72,22 +76,43 @@ static int internal_init_mcrypt(MCRYPT td, void *key, int lenofkey, void *IV)
 			ok = 1;
 	}
 
-	free(sizes);
-	if (ok == 0) {
-		return MCRYPT_KEY_LEN_ERROR;
+
+	if (ok == 0) { /* not supported key size */
+		key_size = mcrypt_enc_get_key_size(td);
+		if (sizes != NULL) {
+			for (i = 0; i < num_of_sizes; i++) {
+				if (lenofkey <= sizes[i]) {
+					key_size = sizes[i];
+					break;
+				}
+			}
+		} else { /* well every key size is supported! */
+			key_size = lenofkey;
+		}
+	} else {
+		key_size = lenofkey;
 	}
 
+	if (sizes!=NULL) free(sizes);
+
 	td->keyword_given = mxcalloc(1, mcrypt_enc_get_key_size(td));
+	if (td->keyword_given==NULL) return MCRYPT_MEMORY_ALLOCATION_ERROR; 
+	
 	memmove(td->keyword_given, key, lenofkey);
 	td->akey = mxcalloc(1, mcrypt_get_size(td));
+	if (td->akey==NULL) return MCRYPT_MEMORY_ALLOCATION_ERROR;
+
 	td->abuf = mxcalloc(1, mcrypt_mode_get_size(td));
+	if (td->abuf==NULL) return MCRYPT_MEMORY_ALLOCATION_ERROR;
 
-	init_mcrypt(td, td->abuf, key, lenofkey, IV);
+	init_mcrypt(td, td->abuf, key, key_size, IV);
 
-	mcrypt_set_key(td,
+	ok = mcrypt_set_key(td,
 		       (void *) td->akey,
 		       (void *) td->keyword_given,
-		       lenofkey, IV, mcrypt_enc_get_iv_size(td));
+		       key_size, IV, IV!=NULL ? mcrypt_enc_get_iv_size(td) : 0);
+
+	if (ok!=0) return MCRYPT_UNKNOWN_ERROR; /* algorithm error */
 
 	if (td->akey == NULL) {
 		internal_end_mcrypt(td);
@@ -144,6 +169,13 @@ int mcrypt_generic_end(const MCRYPT td)
 	return 0;
 }
 
+WIN32DLL_DEFINE
+int mcrypt_generic_deinit(const MCRYPT td)
+{
+	internal_end_mcrypt(td);
+	return 0;
+}
+
 WIN32DLL_DEFINE
 void mcrypt_perror(int err)
 {
@@ -177,6 +209,7 @@ WIN32DLL_DEFINE
 char* mcrypt_strerror(int err)
 {
 char* cerr=malloc(256);
+	if (cerr==NULL) return NULL;
 
 	switch (err) {
 	case MCRYPT_UNKNOWN_ERROR:
