@@ -131,9 +131,10 @@ MCRYPT mcrypt_module_open(char *algorithm,
 			  char *a_directory, char *mode, char *m_directory)
 {
 	MCRYPT td;
-	char* err;
+	const char* err;
 	
 	td = calloc(1, sizeof(CRYPT_STREAM));
+	if (td==NULL) return MCRYPT_FAILED;
 
 	if (lt_dlinit() != 0) {
 		return MCRYPT_FAILED;
@@ -215,10 +216,10 @@ int mcrypt_mode_get_size(MCRYPT td)
 }
 
 WIN32DLL_DEFINE
-void mcrypt_set_key(MCRYPT td, void *a, void *b, int c, void *d, int e)
+int mcrypt_set_key(MCRYPT td, void *a, void *b, int c, void *d, int e)
 {
-	void (*__mcrypt_set_key_stream) (void *, void *, int, void *, int);
-	void (*__mcrypt_set_key_block) (void *, void *, int);
+	int (*__mcrypt_set_key_stream) (void *, void *, int, void *, int);
+	int (*__mcrypt_set_key_block) (void *, void *, int);
 	const char *error;
 	char *s;
 
@@ -229,17 +230,17 @@ void mcrypt_set_key(MCRYPT td, void *a, void *b, int c, void *d, int e)
 		if ((error = lt_dlerror())) {
 			if (error!=NULL) fputs(error, stderr);
 			fputs("\n", stderr);
-			return;
+			return -2;
 		}
-		__mcrypt_set_key_stream(a, b, c, d, e);
+		return __mcrypt_set_key_stream(a, b, c, d, e);
 	} else {
 		__mcrypt_set_key_block = lt_dlsym(s, "_mcrypt_set_key");
 		if ((error = lt_dlerror())) {
 			if (error!=NULL) fputs(error, stderr);
 			fputs("\n", stderr);
-			return;
+			return -2;
 		}
-		__mcrypt_set_key_block(a, b, c);
+		return __mcrypt_set_key_block(a, b, c);
 	}
 }
 
@@ -345,51 +346,6 @@ char *mcrypt_enc_get_algorithms_name(MCRYPT td)
 	return _mcrypt_get_algorithms_name();
 }
 
-WIN32DLL_DEFINE
-void mcrypt_block_encrypt(MCRYPT td, void *b)
-{
-	void (*_mcrypt_block_encrypt) (void *, void *);
-	char *a;
-
-	a = td->akey;
-	_mcrypt_block_encrypt = td->a_encrypt;
-
-	_mcrypt_block_encrypt(a, b);
-}
-
-WIN32DLL_DEFINE
-void mcrypt_block_decrypt(MCRYPT td, void *b)
-{
-	void (*_mcrypt_block_decrypt) (void *, void *);
-	char *a;
-
-	a = td->akey;
-	_mcrypt_block_decrypt = td->a_decrypt;
-	_mcrypt_block_decrypt(a, b);
-}
-
-WIN32DLL_DEFINE
-void mcrypt_stream_encrypt(MCRYPT td, void *b, int c)
-{
-	void (*_mcrypt_stream_encrypt) (void *, void *, int);
-	char *a;
-
-	a = td->akey;
-	_mcrypt_stream_encrypt = td->a_encrypt;
-	_mcrypt_stream_encrypt(a, b, c);
-}
-
-WIN32DLL_DEFINE
-void mcrypt_stream_decrypt(MCRYPT td, void *b, int c)
-{
-	void (*_mcrypt_stream_decrypt) (void *, void *, int);
-	char *a;
-
-	a = td->akey;
-	_mcrypt_stream_decrypt = td->a_decrypt;
-	_mcrypt_stream_decrypt(a, b, c);
-}
-
 WIN32DLL_DEFINE
 int init_mcrypt(MCRYPT td, void *buf, void *a, int b, void *c)
 {
@@ -499,7 +455,7 @@ int mcrypt_module_self_test(char *algorithm, char *a_directory)
 	int i;
 	lt_dlhandle *_handle;
 	int (*_self_test) (void);
-	char* error;
+	const char* error;
 
 
 	if (lt_dlinit() != 0) {
@@ -531,7 +487,7 @@ int mcrypt_module_algorithm_version(char *algorithm, char *a_directory)
 	int i;
 	lt_dlhandle _handle;
 	int (*_version) (void);
-	char* error;
+	const char* error;
 
 	if (lt_dlinit() != 0) {
 		return MCRYPT_UNKNOWN_ERROR;
@@ -562,7 +518,7 @@ int mcrypt_module_mode_version(char *mode, char *m_directory)
 	int i;
 	lt_dlhandle *_handle;
 	int (*_version) (void);
-	char* error;
+	const char* error;
 
 	if (lt_dlinit() != 0) {
 		return MCRYPT_UNKNOWN_ERROR;
@@ -593,7 +549,7 @@ int mcrypt_module_is_block_algorithm(char *algorithm, char *a_directory)
 	int i;
 	lt_dlhandle _handle;
 	int (*_is_block_algorithm) (void);
-	char* error;
+	const char* error;
 	
 	if (lt_dlinit() != 0) {
 		return MCRYPT_UNKNOWN_ERROR;
@@ -625,7 +581,7 @@ int mcrypt_module_is_block_algorithm_mode(char *mode, char *m_directory)
 	int i;
 	lt_dlhandle *_handle;
 	int (*_is_a_block_mode) (void);
-	char* error;
+	const char* error;
 
 	if (lt_dlinit() != 0) {
 		return MCRYPT_UNKNOWN_ERROR;
@@ -656,7 +612,7 @@ int mcrypt_module_is_block_mode(char *mode, char *m_directory)
 	int i;
 	lt_dlhandle *_handle;
 	int (*_is_block_mode) (void);
-	char* error;
+	const char* error;
 
 	if (lt_dlinit() != 0) {
 		return MCRYPT_UNKNOWN_ERROR;
@@ -687,7 +643,7 @@ int mcrypt_module_get_algo_block_size(char *algorithm, char *a_directory)
 	int i;
 	lt_dlhandle _handle;
 	int (*_get_block_size) (void);
-	char* error;
+	const char* error;
 
 	if (lt_dlinit() != 0) {
 		return MCRYPT_UNKNOWN_ERROR;
@@ -718,7 +674,7 @@ int mcrypt_module_get_algo_key_size(char *algorithm, char *a_directory)
 	int i;
 	lt_dlhandle _handle;
 	int (*_get_key_size) (void);
-	char* error;
+	const char* error;
 
 	if (lt_dlinit() != 0) {
 		return MCRYPT_UNKNOWN_ERROR;
@@ -751,7 +707,7 @@ int *mcrypt_module_get_algo_supported_key_sizes(char *algorithm,
 	lt_dlhandle _handle;
 	int *(*_mcrypt_get_key_sizes) (int *);
 	int *size;
-	char* error;
+	const char* error;
 
 	if (lt_dlinit() != 0) {
 		*len = 0;
