@@ -1,5 +1,5 @@
 /* 
- * Copyright (C) 1998,1999,2000 Nikos Mavroyanopoulos
+ * Copyright (C) 1998,1999,2000,2001 Nikos Mavroyanopoulos
  *
  * This library is free software; you can redistribute it and/or modify it 
  * under the terms of the GNU Library General Public License as published 
@@ -37,80 +37,73 @@
 #define _mcrypt_algorithm_version arcfour_LTX__mcrypt_algorithm_version
 #endif
 
+#define swap_byte(x,y) tmp = (x); (x) = (y); (y) = tmp
+
+#define USE_IV /* mcrypt extension */
+void _mcrypt_encrypt(arcfour_key *key, byte *buffer_ptr, int buffer_len);
 
 /* key is the state that should be allocated by the caller */
+#define STATE key->state
+#define I key->i
+#define J key->j
 WIN32DLL_DEFINE
-void _mcrypt_set_key(arcfour_key *key, word8 *key_data, int key_len, char* IV, int iv_len)
+int _mcrypt_set_key(arcfour_key *key, byte *key_data, int key_len, char* IV, int iv_len)
 {
-  word8 tmp, j;
-  word8* state;
-  short i;
-
-  state = key->state;
+  register int tmp, j, i;
+  byte * state = STATE;
+  int ivindex;
   
   for(i = 0; i < 256; i++)
 	  state[i] = i;
 	  
-  key->i = 0;
-  key->j = 0;
+  I = 0;
+  J = 0;
+  ivindex = 0;
  
-  j=0;
-  
-  for(i=0; i<256; i++) {
- 	j = (j+state[i]+key_data[i % key_len]);
-	tmp = state[i];
-	state[i] = state[j];
-	state[j] = tmp;
+  for(j=i=0; i<256; i++) {
+ 	j += state[i]+key_data[i % key_len];
+#ifdef USE_IV
+  	if (iv_len>0 && IV!=NULL) j+= IV[ivindex];
+#endif
+ 	j &= 0xff;
+	swap_byte( state[i], state[j]);
+#ifdef USE_IV
+	if (iv_len>0) ivindex = (ivindex+1) % iv_len;
+#endif
   }
 
-  tmp = j = i = 0;
- 
+  return 0;
 }
 
-#define I key->i
-#define J key->j
-#define STATE key->state
 WIN32DLL_DEFINE
-void _mcrypt_encrypt(arcfour_key *key, word8 *buffer_ptr, int buffer_len)
+void _mcrypt_encrypt(arcfour_key *key, byte *buffer_ptr, int buffer_len)
 {
-  word8 tmp;
-  int counter;
+  register int tmp;
+  register int counter;
+  register int i=I, j=J;
+  byte * state = STATE;
+
   
   for(counter = 0; counter < buffer_len; counter++)
   {
-    I++;
-    J += STATE[I];
+    i++;
+    i &= 0xff;
+    j += state[i];
+    j &= 0xff;
     
-    /* swap STATE[I] and STATE[J] */
-    tmp = STATE[I];
-    STATE[I]=STATE[J];
-    STATE[J]=tmp;
-    
-    tmp = STATE[I]+STATE[J];
-    buffer_ptr[counter] ^= STATE[tmp];
+    /* swap state[i] and state[j] */
+    swap_byte( state[i], state[j]);
+    buffer_ptr[counter] ^= state[(state[i]+tmp) & 0xff];
   }
+  J = j;
+  I = i;
 }
 
 /* this is the same with mcrypt_encrypt */
 WIN32DLL_DEFINE
-void _mcrypt_decrypt(arcfour_key *key, word8 *buffer_ptr, int buffer_len)
+void _mcrypt_decrypt(arcfour_key *key, byte *buffer_ptr, int buffer_len)
 {
-  word8 tmp;
-  int counter;
-  
-  for(counter = 0; counter < buffer_len; counter++)
-  {
-    I++;
-    J += STATE[I];
-    
-    /* swap STATE[I] and STATE[J] */
-    tmp = STATE[I];
-    STATE[I]=STATE[J];
-    STATE[J]=tmp;
-    
-    tmp = STATE[I]+STATE[J];
-    buffer_ptr[counter] ^= STATE[tmp];
-  }
+  _mcrypt_encrypt( key, buffer_ptr, buffer_len);
 }
 
 WIN32DLL_DEFINE
@@ -118,7 +111,7 @@ int _mcrypt_get_size () {return sizeof(arcfour_key);}
 WIN32DLL_DEFINE
 int _mcrypt_get_block_size() { return 1; }
 WIN32DLL_DEFINE
-int _mcrypt_get_algo_iv_size() { return 0; }
+int _mcrypt_get_algo_iv_size() { return 32; }
 WIN32DLL_DEFINE
 int _is_block_algorithm() { return 0; }
 WIN32DLL_DEFINE
@@ -180,6 +173,6 @@ int _mcrypt_self_test() {
 
 WIN32DLL_DEFINE
 word32 _mcrypt_algorithm_version() {
-        return 20001001;
+        return 20010123;
 }
 
