@@ -7,52 +7,41 @@
  * All modifications are placed under the license of libmcrypt.
  */
 
-/* $Id: blowfish.c,v 1.6 2000/11/08 23:25:36 nmav Exp $ */
+/* $Id: blowfish.c,v 1.13 2001/01/23 11:51:19 nmav Exp $ */
 
 #include "../../lib/libdefs.h"
 #include "../../lib/mcrypt_modules.h"
 #include "blowfish.h"
 
 #ifdef USE_LTDL
-#define _mcrypt_set_key blowfish_LTX__mcrypt_set_key
-#define _mcrypt_encrypt blowfish_LTX__mcrypt_encrypt
-#define _mcrypt_decrypt blowfish_LTX__mcrypt_decrypt
-#define _mcrypt_get_size blowfish_LTX__mcrypt_get_size
-#define _mcrypt_get_block_size blowfish_LTX__mcrypt_get_block_size
-#define _is_block_algorithm blowfish_LTX__is_block_algorithm
-#define _mcrypt_get_key_size blowfish_LTX__mcrypt_get_key_size
-#define _mcrypt_get_supported_key_sizes blowfish_LTX__mcrypt_get_supported_key_sizes
-#define _mcrypt_get_algorithms_name blowfish_LTX__mcrypt_get_algorithms_name
-#define _mcrypt_self_test blowfish_LTX__mcrypt_self_test
-#define _mcrypt_algorithm_version blowfish_LTX__mcrypt_algorithm_version
+#define _mcrypt_set_key blowfish_compat_LTX__mcrypt_set_key
+#define _mcrypt_encrypt blowfish_compat_LTX__mcrypt_encrypt
+#define _mcrypt_decrypt blowfish_compat_LTX__mcrypt_decrypt
+#define _mcrypt_get_size blowfish_compat_LTX__mcrypt_get_size
+#define _mcrypt_get_block_size blowfish_compat_LTX__mcrypt_get_block_size
+#define _is_block_algorithm blowfish_compat_LTX__is_block_algorithm
+#define _mcrypt_get_key_size blowfish_compat_LTX__mcrypt_get_key_size
+#define _mcrypt_get_supported_key_sizes blowfish_compat_LTX__mcrypt_get_supported_key_sizes
+#define _mcrypt_get_algorithms_name blowfish_compat_LTX__mcrypt_get_algorithms_name
+#define _mcrypt_self_test blowfish_compat_LTX__mcrypt_self_test
+#define _mcrypt_algorithm_version blowfish_compat_LTX__mcrypt_algorithm_version
 #endif
 
-/*
-typedef struct {
-         word32 S[4][256],P[18];
-} blf_ctx;
-*/
-
 #define MAXKEYBYTES 56		/* 448 bits */
-
 #define BF_N         16
 #define KEYBYTES   8
 
-static word32 F(blf_ctx * bc, word32 x)
-{
-	return ((bc->S[0][(x >> 24) & 0xff] + bc->S[1][(x >> 16) & 0xff]) ^ bc->S[2][(x >>  8) & 0xff]) + bc->S[3][(x      ) & 0xff];
-
-}
+#define F(bc, x) ( ((bc->S[0][(x >> 24) & 0xff] + bc->S[1][(x >> 16) & 0xff]) ^ bc->S[2][(x >>  8) & 0xff]) + bc->S[3][x & 0xff] )
 
 /* x should be a 64 bit integer */
 WIN32DLL_DEFINE
 void _mcrypt_encrypt(blf_ctx * c, word32 * x)
 {
-	word32 Xl;
-	word32 Xr, temp;
+	register word32 Xl;
+	register word32 Xr, temp;
 	short i;
 
-#ifndef WORDS_BIGENDIAN
+#ifdef WORDS_BIGENDIAN
 	Xl = x[0];
 	Xr = x[1];
 #else
@@ -76,7 +65,7 @@ for (i = 0; i < BF_N; ++i) {
 	Xr ^= c->P[BF_N];
 	Xl ^= c->P[BF_N + 1];
 
-#ifndef WORDS_BIGENDIAN
+#ifdef WORDS_BIGENDIAN
 	x[0] = Xl;
 	x[1] = Xr;
 #else
@@ -89,8 +78,8 @@ for (i = 0; i < BF_N; ++i) {
 /* x should be a 64 bit integer */
 static void enblf_noswap(blf_ctx * c, word32 * x)
 {				/* Used internally */
-	word32 Xl;
-	word32 Xr, temp;
+	register word32 Xl;
+	register word32 Xr, temp;
 	short i;
 
 	Xl = x[0];
@@ -119,10 +108,10 @@ static void enblf_noswap(blf_ctx * c, word32 * x)
 WIN32DLL_DEFINE
 void _mcrypt_decrypt(blf_ctx * c, word32 * x)
 {
-	word32 Xl, Xr, temp;
-	short i;
+	register word32 Xl, Xr, temp;
+	register short i;
 
-#ifndef WORDS_BIGENDIAN
+#ifdef WORDS_BIGENDIAN
 	Xl = x[0];
 	Xr = x[1];
 #else
@@ -146,7 +135,7 @@ void _mcrypt_decrypt(blf_ctx * c, word32 * x)
 	Xr ^= c->P[1];
 	Xl ^= c->P[0];
 
-#ifndef WORDS_BIGENDIAN
+#ifdef WORDS_BIGENDIAN
 	x[0] = Xl;
 	x[1] = Xr;
 #else
@@ -572,9 +561,10 @@ static short initialize_blowfish(blf_ctx * c, unsigned char key[], short keybyte
 }
 
 WIN32DLL_DEFINE
-void _mcrypt_set_key(blf_ctx * c, char *k, int len)
+int _mcrypt_set_key(blf_ctx * c, char *k, int len)
 {
 	initialize_blowfish(c, k, len);
+	return 0;
 }
 
 WIN32DLL_DEFINE
@@ -593,7 +583,7 @@ int* _mcrypt_get_supported_key_sizes(int *len) {
 WIN32DLL_DEFINE
 char * _mcrypt_get_algorithms_name() { char*x; x=malloc(10); strcpy(x, "Blowfish"); return x;}
 
-#define CIPHER "de8e9a3a9cd44280"
+#define CIPHER "c8c033bc57874d74"
 
 WIN32DLL_DEFINE
 int _mcrypt_self_test() {
@@ -640,5 +630,5 @@ int _mcrypt_self_test() {
 
 WIN32DLL_DEFINE
 word32 _mcrypt_algorithm_version() {
-	return 19991129;
+	return 20010111;
 }
