@@ -26,7 +26,7 @@
  * All modifications are placed under the license of libmcrypt.
  */
 
-/* $Id: gost.c,v 1.4 2000/10/12 21:06:31 nmav Exp $ */
+/* $Id: gost.c,v 1.5 2001/01/22 22:13:19 nmav Exp $ */
 
 /*
  * If you read the standard, it belabors the point of copying corresponding
@@ -116,7 +116,7 @@ static unsigned char k21[256];
  */
 
 WIN32DLL_DEFINE
-void _mcrypt_set_key (word32 *inst, word32* key, int len) {
+int _mcrypt_set_key (word32 *inst, word32* key, int len) {
 
 	_mcrypt_kboxinit();
 	inst[0] = 0;	inst[1] = 0;
@@ -134,6 +134,7 @@ void _mcrypt_set_key (word32 *inst, word32* key, int len) {
 	inst[6] = byteswap32(inst[6]);
 	inst[7] = byteswap32(inst[7]);
 #endif
+return 0;
 }
 
 void _mcrypt_kboxinit(void)
