@@ -20,7 +20,7 @@
  */
 
 
-/* $Id: rijndael-192.c,v 1.3 2000/10/12 21:06:31 nmav Exp $ */
+/* $Id: rijndael-192.c,v 1.6 2001/01/23 12:09:44 nmav Exp $ */
 
 #include "../../lib/libdefs.h"
 #include "../../lib/mcrypt_modules.h"
@@ -52,11 +52,11 @@
 
 /* Fixed Data */
 
-static word8 InCo[4]={0xB,0xD,0x9,0xE};  /* Inverse Coefficients */
+static byte InCo[4]={0xB,0xD,0x9,0xE};  /* Inverse Coefficients */
 
-static word8 fbsub[256];
-static word8 rbsub[256];
-static word8 ptab[256],ltab[256];
+static byte fbsub[256];
+static byte rbsub[256];
+static byte ptab[256],ltab[256];
 static word32 ftable[256];
 static word32 rtable[256];
 static word32 rco[30];
@@ -66,22 +66,22 @@ static int tables_ok=0;
 
 /* in "rijndael.h" */
 
-static word32 pack(word8 *b)
+static word32 pack(byte *b)
 { /* pack bytes into a 32-bit Word */
     return ((word32)b[3]<<24)|((word32)b[2]<<16)|((word32)b[1]<<8)|(word32)b[0];
 }
 
-static void unpack(word32 a,word8 *b)
+static void unpack(word32 a,byte *b)
 { /* unpack bytes from a word */
-    b[0]=(word8)a;
-    b[1]=(word8)(a>>8);
-    b[2]=(word8)(a>>16);
-    b[3]=(word8)(a>>24);
+    b[0]=(byte)a;
+    b[1]=(byte)(a>>8);
+    b[2]=(byte)(a>>16);
+    b[3]=(byte)(a>>24);
 }
 
-static word8 xtime(word8 a)
+static byte xtime(byte a)
 {
-    word8 b;
+    byte b;
     if (a&0x80) b=0x1B;
     else        b=0;
     a<<=1;
@@ -89,7 +89,7 @@ static word8 xtime(word8 a)
     return a;
 }
 
-static word8 bmul(word8 x,word8 y)
+static byte bmul(byte x,byte y)
 { /* x.y= AntiLog(Log(x) + Log(y)) */
     if (x && y) return ptab[(ltab[x]+ltab[y])%255];
     else return 0;
@@ -97,7 +97,7 @@ static word8 bmul(word8 x,word8 y)
 
 static word32 SubByte(word32 a)
 {
-    word8 b[4];
+    byte b[4];
     unpack(a,b);
     b[0]=fbsub[b[0]];
     b[1]=fbsub[b[1]];
@@ -106,9 +106,9 @@ static word32 SubByte(word32 a)
     return pack(b);    
 }
 
-static word8 product(word32 x,word32 y)
+static byte product(word32 x,word32 y)
 { /* dot product of two 4-byte arrays */
-    word8 xb[4],yb[4];
+    byte xb[4],yb[4];
     unpack(x,xb);
     unpack(y,yb); 
     return bmul(xb[0],yb[0])^bmul(xb[1],yb[1])^bmul(xb[2],yb[2])^bmul(xb[3],yb[3]);
@@ -117,7 +117,7 @@ static word8 product(word32 x,word32 y)
 static word32 InvMixCol(word32 x)
 { /* matrix Multiplication */
     word32 y,m;
-    word8 b[4];
+    byte b[4];
 
     m=pack(InCo);
     b[3]=product(m,x);
@@ -131,9 +131,9 @@ static word32 InvMixCol(word32 x)
     return y;
 }
 
-word8 ByteSub(word8 x)
+byte ByteSub(byte x)
 {
-    word8 y=ptab[255-ltab[x]];  /* multiplicative inverse */
+    byte y=ptab[255-ltab[x]];  /* multiplicative inverse */
     x=y;  x=ROTL(x);
     y^=x; x=ROTL(x);
     y^=x; x=ROTL(x);
@@ -145,7 +145,7 @@ word8 ByteSub(word8 x)
 void _mcrypt_rijndael_gentables(void)
 { /* generate tables */
     int i;
-    word8 y,b[4];
+    byte y,b[4];
 
   /* use 3 as primitive root to generate power and log tables */
 
@@ -164,7 +164,7 @@ void _mcrypt_rijndael_gentables(void)
     rbsub[0x63]=0;
     for (i=1;i<256;i++)
     {
-        y=ByteSub((word8)i);
+        y=ByteSub((byte)i);
         fbsub[i]=y; rbsub[y]=i;
     }
 
@@ -190,7 +190,7 @@ void _mcrypt_rijndael_gentables(void)
 }
 
 WIN32DLL_DEFINE
-void _mcrypt_set_key( RI* rinst, word8 *key, int nk)
+int _mcrypt_set_key( RI* rinst, byte *key, int nk)
 { /* blocksize=32*nb bits. Key=32*nk bits */
   /* currently nb,bk = 4, 6 or 8          */
   /* key comes as 4*rinst->Nk bytes              */
@@ -263,6 +263,7 @@ void _mcrypt_set_key( RI* rinst, word8 *key, int nk)
         for (j=0;j<rinst->Nb;j++) rinst->rkey[k+j]=InvMixCol(rinst->fkey[i+j]);
     }
     for (j=N-rinst->Nb;j<N;j++) rinst->rkey[j-N+rinst->Nb]=rinst->fkey[j];
+return 0;
 }
 
 
@@ -271,7 +272,7 @@ void _mcrypt_set_key( RI* rinst, word8 *key, int nk)
  * 3 pre-rotated to save the ROTL8, ROTL16 and ROTL24 overhead */ 
 
 WIN32DLL_DEFINE
-void _mcrypt_encrypt(RI *rinst, word8 *buff)
+void _mcrypt_encrypt(RI *rinst, byte *buff)
 {
     int i,j,k,m;
     word32 a[8],b[8],*x,*y,*t;
@@ -294,9 +295,9 @@ void _mcrypt_encrypt(RI *rinst, word8 *buff)
         for (m=j=0;j<rinst->Nb;j++,m+=3)
         { /* deal with each 32-bit element of the State */
           /* This is the time-critical bit */
-            y[j]=rinst->fkey[k++]^ftable[(word8)x[j]]^
-                 ROTL8(ftable[(word8)(x[rinst->fi[m]]>>8)])^
-                 ROTL16(ftable[(word8)(x[rinst->fi[m+1]]>>16)])^
+            y[j]=rinst->fkey[k++]^ftable[(byte)x[j]]^
+                 ROTL8(ftable[(byte)(x[rinst->fi[m]]>>8)])^
+                 ROTL16(ftable[(byte)(x[rinst->fi[m+1]]>>16)])^
                  ROTL24(ftable[x[rinst->fi[m+2]]>>24]);
         }
         t=x; x=y; y=t;      /* swap pointers */
@@ -305,9 +306,9 @@ void _mcrypt_encrypt(RI *rinst, word8 *buff)
 /* Last Round - unroll if possible */ 
     for (m=j=0;j<rinst->Nb;j++,m+=3)
     {
-        y[j]=rinst->fkey[k++]^(word32)fbsub[(word8)x[j]]^
-             ROTL8((word32)fbsub[(word8)(x[rinst->fi[m]]>>8)])^
-             ROTL16((word32)fbsub[(word8)(x[rinst->fi[m+1]]>>16)])^
+        y[j]=rinst->fkey[k++]^(word32)fbsub[(byte)x[j]]^
+             ROTL8((word32)fbsub[(byte)(x[rinst->fi[m]]>>8)])^
+             ROTL16((word32)fbsub[(byte)(x[rinst->fi[m+1]]>>16)])^
              ROTL24((word32)fbsub[x[rinst->fi[m+2]]>>24]);
     }   
     for (i=j=0;i<rinst->Nb;i++,j+=4)
@@ -319,7 +320,7 @@ void _mcrypt_encrypt(RI *rinst, word8 *buff)
 }
 
 WIN32DLL_DEFINE
-void _mcrypt_decrypt(RI *rinst, word8 *buff)
+void _mcrypt_decrypt(RI *rinst, byte *buff)
 {
     int i,j,k,m;
     word32 a[8],b[8],*x,*y,*t;
@@ -341,9 +342,9 @@ void _mcrypt_decrypt(RI *rinst, word8 *buff)
 
         for (m=j=0;j<rinst->Nb;j++,m+=3)
         { /* This is the time-critical bit */
-            y[j]=rinst->rkey[k++]^rtable[(word8)x[j]]^
-                 ROTL8(rtable[(word8)(x[rinst->ri[m]]>>8)])^
-                 ROTL16(rtable[(word8)(x[rinst->ri[m+1]]>>16)])^
+            y[j]=rinst->rkey[k++]^rtable[(byte)x[j]]^
+                 ROTL8(rtable[(byte)(x[rinst->ri[m]]>>8)])^
+                 ROTL16(rtable[(byte)(x[rinst->ri[m+1]]>>16)])^
                  ROTL24(rtable[x[rinst->ri[m+2]]>>24]);
         }
         t=x; x=y; y=t;      /* swap pointers */
@@ -352,9 +353,9 @@ void _mcrypt_decrypt(RI *rinst, word8 *buff)
 /* Last Round - unroll if possible */ 
     for (m=j=0;j<rinst->Nb;j++,m+=3)
     {
-        y[j]=rinst->rkey[k++]^(word32)rbsub[(word8)x[j]]^
-             ROTL8((word32)rbsub[(word8)(x[rinst->ri[m]]>>8)])^
-             ROTL16((word32)rbsub[(word8)(x[rinst->ri[m+1]]>>16)])^
+        y[j]=rinst->rkey[k++]^(word32)rbsub[(byte)x[j]]^
+             ROTL8((word32)rbsub[(byte)(x[rinst->ri[m]]>>8)])^
+             ROTL16((word32)rbsub[(byte)(x[rinst->ri[m+1]]>>16)])^
              ROTL24((word32)rbsub[x[rinst->ri[m+2]]>>24]);
     }        
     for (i=j=0;i<rinst->Nb;i++,j+=4)
