@@ -19,7 +19,7 @@
  * All modifications are placed under the license of libmcrypt.
  */
 
-/* $Id: rijndael-256.c,v 1.4 2001/01/03 23:22:24 nmav Exp $ */
+/* $Id: rijndael-256.c,v 1.6 2001/01/23 11:51:19 nmav Exp $ */
 
 #include "../../lib/libdefs.h"
 #include "../../lib/mcrypt_modules.h"
@@ -51,11 +51,11 @@
 
 /* Fixed Data */
 
-static word8 InCo[4] = { 0xB, 0xD, 0x9, 0xE };	/* Inverse Coefficients */
+static byte InCo[4] = { 0xB, 0xD, 0x9, 0xE };	/* Inverse Coefficients */
 
-static word8 fbsub[256];
-static word8 rbsub[256];
-static word8 ptab[256], ltab[256];
+static byte fbsub[256];
+static byte rbsub[256];
+static byte ptab[256], ltab[256];
 static word32 ftable[256];
 static word32 rtable[256];
 static word32 rco[30];
@@ -65,24 +65,24 @@ static int tables_ok = 0;
 
 /* in "rijndael.h" */
 
-static word32 pack(word8 * b)
+static word32 pack(byte * b)
 {				/* pack bytes into a 32-bit Word */
 	return ((word32) b[3] << 24) | ((word32) b[2] << 16) | ((word32)
 								b[1] << 8)
 	    | (word32) b[0];
 }
 
-static void unpack(word32 a, word8 * b)
+static void unpack(word32 a, byte * b)
 {				/* unpack bytes from a word */
-	b[0] = (word8) a;
-	b[1] = (word8) (a >> 8);
-	b[2] = (word8) (a >> 16);
-	b[3] = (word8) (a >> 24);
+	b[0] = (byte) a;
+	b[1] = (byte) (a >> 8);
+	b[2] = (byte) (a >> 16);
+	b[3] = (byte) (a >> 24);
 }
 
-static word8 xtime(word8 a)
+static byte xtime(byte a)
 {
-	word8 b;
+	byte b;
 	if (a & 0x80)
 		b = 0x1B;
 	else
@@ -92,7 +92,7 @@ static word8 xtime(word8 a)
 	return a;
 }
 
-static word8 bmul(word8 x, word8 y)
+static byte bmul(byte x, byte y)
 {				/* x.y= AntiLog(Log(x) + Log(y)) */
 	if (x && y)
 		return ptab[(ltab[x] + ltab[y]) % 255];
@@ -102,7 +102,7 @@ static word8 bmul(word8 x, word8 y)
 
 static word32 SubByte(word32 a)
 {
-	word8 b[4];
+	byte b[4];
 	unpack(a, b);
 	b[0] = fbsub[b[0]];
 	b[1] = fbsub[b[1]];
@@ -111,9 +111,9 @@ static word32 SubByte(word32 a)
 	return pack(b);
 }
 
-static word8 product(word32 x, word32 y)
+static byte product(word32 x, word32 y)
 {				/* dot product of two 4-byte arrays */
-	word8 xb[4], yb[4];
+	byte xb[4], yb[4];
 	unpack(x, xb);
 	unpack(y, yb);
 	return bmul(xb[0], yb[0]) ^ bmul(xb[1], yb[1]) ^ bmul(xb[2],
@@ -124,7 +124,7 @@ static word8 product(word32 x, word32 y)
 static word32 InvMixCol(word32 x)
 {				/* matrix Multiplication */
 	word32 y, m;
-	word8 b[4];
+	byte b[4];
 
 	m = pack(InCo);
 	b[3] = product(m, x);
@@ -138,9 +138,9 @@ static word32 InvMixCol(word32 x)
 	return y;
 }
 
-word8 ByteSub(word8 x)
+byte ByteSub(byte x)
 {
-	word8 y = ptab[255 - ltab[x]];	/* multiplicative inverse */
+	byte y = ptab[255 - ltab[x]];	/* multiplicative inverse */
 	x = y;
 	x = ROTL(x);
 	y ^= x;
@@ -157,7 +157,7 @@ word8 ByteSub(word8 x)
 void _mcrypt_rijndael_gentables(void)
 {				/* generate tables */
 	int i;
-	word8 y, b[4];
+	byte y, b[4];
 
 	/* use 3 as primitive root to generate power and log tables */
 
@@ -176,7 +176,7 @@ void _mcrypt_rijndael_gentables(void)
 	fbsub[0] = 0x63;
 	rbsub[0x63] = 0;
 	for (i = 1; i < 256; i++) {
-		y = ByteSub((word8) i);
+		y = ByteSub((byte) i);
 		fbsub[i] = y;
 		rbsub[y] = i;
 	}
@@ -205,7 +205,7 @@ void _mcrypt_rijndael_gentables(void)
 }
 
 WIN32DLL_DEFINE
-void _mcrypt_set_key(RI * rinst, word8 * key, int nk)
+int _mcrypt_set_key(RI * rinst, byte * key, int nk)
 {				/* blocksize=32*nb bits. Key=32*nk bits */
 	/* currently nb,bk = 4, 6 or 8          */
 	/* key comes as 4*rinst->Nk bytes              */
@@ -302,6 +302,7 @@ void _mcrypt_set_key(RI * rinst, word8 * key, int nk)
 	}
 	for (j = N - rinst->Nb; j < N; j++)
 		rinst->rkey[j - N + rinst->Nb] = rinst->fkey[j];
+return 0;
 }
 
 
@@ -310,7 +311,7 @@ void _mcrypt_set_key(RI * rinst, word8 * key, int nk)
  * 3 pre-rotated to save the ROTL8, ROTL16 and ROTL24 overhead */
 
 WIN32DLL_DEFINE
-void _mcrypt_encrypt(RI * rinst, word8 * buff)
+void _mcrypt_encrypt(RI * rinst, byte * buff)
 {
 	int i, j, k, m;
 	word32 a[8], b[8], *x, *y, *t;
@@ -331,10 +332,10 @@ void _mcrypt_encrypt(RI * rinst, word8 * buff)
 
 		for (m = j = 0; j < rinst->Nb; j++, m += 3) {	/* deal with each 32-bit element of the State */
 			/* This is the time-critical bit */
-			y[j] = rinst->fkey[k++] ^ ftable[(word8) x[j]] ^
-			    ROTL8(ftable[(word8) (x[rinst->fi[m]] >> 8)]) ^
+			y[j] = rinst->fkey[k++] ^ ftable[(byte) x[j]] ^
+			    ROTL8(ftable[(byte) (x[rinst->fi[m]] >> 8)]) ^
 			    ROTL16(ftable
-				   [(word8) (x[rinst->fi[m + 1]] >> 16)]) ^
+				   [(byte) (x[rinst->fi[m + 1]] >> 16)]) ^
 			    ROTL24(ftable[x[rinst->fi[m + 2]] >> 24]);
 		}
 		t = x;
@@ -344,10 +345,10 @@ void _mcrypt_encrypt(RI * rinst, word8 * buff)
 
 /* Last Round - unroll if possible */
 	for (m = j = 0; j < rinst->Nb; j++, m += 3) {
-		y[j] = rinst->fkey[k++] ^ (word32) fbsub[(word8) x[j]] ^
-		    ROTL8((word32) fbsub[(word8) (x[rinst->fi[m]] >> 8)]) ^
+		y[j] = rinst->fkey[k++] ^ (word32) fbsub[(byte) x[j]] ^
+		    ROTL8((word32) fbsub[(byte) (x[rinst->fi[m]] >> 8)]) ^
 		    ROTL16((word32)
-			   fbsub[(word8) (x[rinst->fi[m + 1]] >> 16)]) ^
+			   fbsub[(byte) (x[rinst->fi[m + 1]] >> 16)]) ^
 		    ROTL24((word32) fbsub[x[rinst->fi[m + 2]] >> 24]);
 	}
 	for (i = j = 0; i < rinst->Nb; i++, j += 4) {
@@ -358,7 +359,7 @@ void _mcrypt_encrypt(RI * rinst, word8 * buff)
 }
 
 WIN32DLL_DEFINE
-void _mcrypt_decrypt(RI * rinst, word8 * buff)
+void _mcrypt_decrypt(RI * rinst, byte * buff)
 {
 	int i, j, k, m;
 	word32 a[8], b[8], *x, *y, *t;
@@ -378,10 +379,10 @@ void _mcrypt_decrypt(RI * rinst, word8 * buff)
    loop and hard-code in the values of ri[]  */
 
 		for (m = j = 0; j < rinst->Nb; j++, m += 3) {	/* This is the time-critical bit */
-			y[j] = rinst->rkey[k++] ^ rtable[(word8) x[j]] ^
-			    ROTL8(rtable[(word8) (x[rinst->ri[m]] >> 8)]) ^
+			y[j] = rinst->rkey[k++] ^ rtable[(byte) x[j]] ^
+			    ROTL8(rtable[(byte) (x[rinst->ri[m]] >> 8)]) ^
 			    ROTL16(rtable
-				   [(word8) (x[rinst->ri[m + 1]] >> 16)]) ^
+				   [(byte) (x[rinst->ri[m + 1]] >> 16)]) ^
 			    ROTL24(rtable[x[rinst->ri[m + 2]] >> 24]);
 		}
 		t = x;
@@ -391,10 +392,10 @@ void _mcrypt_decrypt(RI * rinst, word8 * buff)
 
 /* Last Round - unroll if possible */
 	for (m = j = 0; j < rinst->Nb; j++, m += 3) {
-		y[j] = rinst->rkey[k++] ^ (word32) rbsub[(word8) x[j]] ^
-		    ROTL8((word32) rbsub[(word8) (x[rinst->ri[m]] >> 8)]) ^
+		y[j] = rinst->rkey[k++] ^ (word32) rbsub[(byte) x[j]] ^
+		    ROTL8((word32) rbsub[(byte) (x[rinst->ri[m]] >> 8)]) ^
 		    ROTL16((word32)
-			   rbsub[(word8) (x[rinst->ri[m + 1]] >> 16)]) ^
+			   rbsub[(byte) (x[rinst->ri[m + 1]] >> 16)]) ^
 		    ROTL24((word32) rbsub[x[rinst->ri[m + 2]] >> 24]);
 	}
 	for (i = j = 0; i < rinst->Nb; i++, j += 4) {
