@@ -21,7 +21,7 @@
  * All modifications are placed under the license of libmcrypt.
  */
 
-/* $Id: safer64.c,v 1.3 2000/10/12 21:06:31 nmav Exp $ */
+/* $Id: safer64.c,v 1.4 2001/01/22 22:13:19 nmav Exp $ */
 
 /******************* External Headers *****************************************/
 
@@ -83,7 +83,7 @@ void _mcrypt_Safer_Init_Module(void)
 /******************************************************************************/
 
 WIN32DLL_DEFINE
-void _mcrypt_set_key(safer_key_t * key, safer_block_t * userkey, int len)
+int _mcrypt_set_key(safer_key_t * key, safer_block_t * userkey, int len)
 {
 	unsigned int i, j;
 	unsigned char ka[SAFER_BLOCK_LEN + 1];
@@ -138,6 +138,7 @@ void _mcrypt_set_key(safer_key_t * key, safer_block_t * userkey, int len)
 	}
 	for (j = 0; j < SAFER_BLOCK_LEN + 1; j++)
 		ka[j] = kb[j] = 0;
+return 0;
 }				/* Safer_Expand_Userkey */
 
 /******************************************************************************/
