@@ -12,7 +12,7 @@
 /*                                                                      */
 /* Dr Brian Gladman (gladman@seven77.demon.co.uk) 14th January 1999     */
 
-/* $Id: saferplus.c,v 1.3 2000/10/12 21:06:31 nmav Exp $ */
+/* $Id: saferplus.c,v 1.5 2001/01/23 11:51:19 nmav Exp $ */
 
 /* modified in order to use the libmcrypt API by Nikos Mavroyanopoulos 
  * All modifications are placed under the license of libmcrypt.
@@ -82,7 +82,7 @@ Mean:         3392 cycles =     7.5 mbits/sec
 #define _mcrypt_algorithm_version saferplus_LTX__mcrypt_algorithm_version
 #endif
 
-word8 safer_expf[256] =
+byte safer_expf[256] =
     { 1, 45, 226, 147, 190, 69, 21, 174, 120, 3, 135, 164, 184, 56, 207,
 	63,
 	8, 103, 9, 148, 235, 38, 168, 107, 189, 24, 52, 27, 187, 191, 114,
@@ -117,7 +117,7 @@ word8 safer_expf[256] =
 	40
 };
 
-word8 safer_logf[512] = {
+byte safer_logf[512] = {
 	128, 0, 176, 9, 96, 239, 185, 253, 16, 18, 159, 228, 105, 186, 173,
 	248,
 	192, 56, 194, 101, 79, 6, 148, 252, 25, 222, 106, 27, 93, 78, 168,
@@ -186,14 +186,14 @@ word8 safer_logf[512] = {
 };
 
 
-/* word8  l_key[33 * 16]; */
+/* byte  l_key[33 * 16]; */
 /* word32  k_bytes; */
 
 WIN32DLL_DEFINE
-void _mcrypt_set_key(SPI * sp_key, const word32 * in_key,
+int _mcrypt_set_key(SPI * sp_key, const word32 * in_key,
 			       const word32 key_len)
 {
-	word8 by, lk[33];
+	byte by, lk[33];
 	word32 i, j, k, l, m, *lkp = (void *) lk;
 
 	for (i = 0; i < 33; i++)
@@ -238,11 +238,12 @@ void _mcrypt_set_key(SPI * sp_key, const word32 * in_key,
 			}
 		}
 	}
+	return 0;
 }
 
-void do_fr(word8 x[16], word8 * kp)
+void do_fr(byte x[16], byte * kp)
 {
-	word8 t;
+	byte t;
 
 	x[0] = safer_expf[x[0] ^ kp[0]] + kp[16];
 	x[1] = safer_logf[x[1] + kp[1]] ^ kp[17];
@@ -353,9 +354,9 @@ void do_fr(word8 x[16], word8 * kp)
 	x[3] = t;
 }
 
-void do_ir(word8 x[16], word8 * kp)
+void do_ir(byte x[16], byte * kp)
 {
-	word8 t;
+	byte t;
 
 	t = x[3];
 	x[3] = x[15];
@@ -469,9 +470,9 @@ void do_ir(word8 x[16], word8 * kp)
 WIN32DLL_DEFINE
 void _mcrypt_encrypt(SPI * spi, word32 * _blk)
 {
-	word8 *kp;
+	byte *kp;
 	word32 __blk[16];
-	word8 *blk = (void *) __blk;
+	byte *blk = (void *) __blk;
 
 	__blk[3] = _blk[0];
 	__blk[2] = _blk[1];
@@ -531,9 +532,9 @@ void _mcrypt_encrypt(SPI * spi, word32 * _blk)
 WIN32DLL_DEFINE
 void _mcrypt_decrypt(SPI * spi, word32 * _blk)
 {
-	word8 *kp;
+	byte *kp;
 	word32 __blk[16];
-	word8 *blk = (void *) __blk;
+	byte *blk = (void *) __blk;
 
 	__blk[3] = _blk[0];
 	__blk[2] = _blk[1];
