@@ -16,7 +16,7 @@
  * All modifications are placed under the license of libmcrypt.
  */
  
-/* $Id: tripledes.c,v 1.4 2000/10/12 21:06:31 nmav Exp $ */
+/* $Id: tripledes.c,v 1.5 2001/01/22 22:13:19 nmav Exp $ */
 
 #include "../../lib/libdefs.h"
 #include "../../lib/mcrypt_modules.h"
@@ -211,7 +211,7 @@ int _mcrypt_desinit(TRIPLEDES_KEY* key)
 
 /* Set key (initialize key schedule array) */
 WIN32DLL_DEFINE
-void _mcrypt_set_key(TRIPLEDES_KEY* dkey, char* user_key, int len)
+int _mcrypt_set_key(TRIPLEDES_KEY* dkey, char* user_key, int len)
 {
 	char pc1m[56];		/* place to modify pc1 into */
 	char pcr[56];		/* place to rotate pc1 into */
@@ -300,6 +300,7 @@ void _mcrypt_set_key(TRIPLEDES_KEY* dkey, char* user_key, int len)
 			}
 		}
 	}
+return 0;
 }
 
 
