@@ -20,7 +20,7 @@
  * All modifications are placed under the license of libmcrypt.
  */
 
-/* $Id: twofish.c,v 1.4 2000/10/12 21:06:31 nmav Exp $ */
+/* $Id: twofish.c,v 1.6 2001/01/23 11:51:19 nmav Exp $ */
 
 /* Timing data for Twofish (twofish.c)
 
@@ -68,46 +68,46 @@
  */
 
 /* Extract byte from a 32 bit quantity (little endian notation)     */
-#define byte(x,n)   ((word8)((x) >> (8 * n)))
+#define byte(x,n)   ((byte)((x) >> (8 * n)))
 
 /* finite field arithmetic for GF(2**8) with the modular    */
 /* polynomial x^8 + x^6 + x^5 + x^3 + 1 (0x169)             */
 
 #define G_M 0x0169
 
-word8 tab_5b[4] = { 0, G_M >> 2, G_M >> 1, (G_M >> 1) ^ (G_M >> 2) };
-word8 tab_ef[4] = { 0, (G_M >> 1) ^ (G_M >> 2), G_M >> 1, G_M >> 2 };
+byte tab_5b[4] = { 0, G_M >> 2, G_M >> 1, (G_M >> 1) ^ (G_M >> 2) };
+byte tab_ef[4] = { 0, (G_M >> 1) ^ (G_M >> 2), G_M >> 1, G_M >> 2 };
 
 #define ffm_01(x)    (x)
 #define ffm_5b(x)   ((x) ^ ((x) >> 2) ^ tab_5b[(x) & 3])
 #define ffm_ef(x)   ((x) ^ ((x) >> 1) ^ ((x) >> 2) ^ tab_ef[(x) & 3])
 
-word8 ror4[16] = { 0, 8, 1, 9, 2, 10, 3, 11, 4, 12, 5, 13, 6, 14, 7, 15 };
-word8 ashx[16] = { 0, 9, 2, 11, 4, 13, 6, 15, 8, 1, 10, 3, 12, 5, 14, 7 };
+byte ror4[16] = { 0, 8, 1, 9, 2, 10, 3, 11, 4, 12, 5, 13, 6, 14, 7, 15 };
+byte ashx[16] = { 0, 9, 2, 11, 4, 13, 6, 15, 8, 1, 10, 3, 12, 5, 14, 7 };
 
-word8 qt0[2][16] = {
+byte qt0[2][16] = {
 	{8, 1, 7, 13, 6, 15, 3, 2, 0, 11, 5, 9, 14, 12, 10, 4},
 	{2, 8, 11, 13, 15, 7, 6, 14, 3, 1, 9, 4, 0, 10, 12, 5}
 };
 
-word8 qt1[2][16] = {
+byte qt1[2][16] = {
 	{14, 12, 11, 8, 1, 2, 3, 5, 15, 4, 10, 6, 7, 0, 9, 13},
 	{1, 14, 2, 11, 4, 12, 3, 7, 6, 13, 10, 5, 15, 9, 0, 8}
 };
 
-word8 qt2[2][16] = {
+byte qt2[2][16] = {
 	{11, 10, 5, 14, 6, 13, 9, 0, 12, 8, 15, 3, 2, 4, 7, 1},
 	{4, 12, 7, 5, 1, 6, 9, 10, 0, 14, 13, 8, 2, 11, 3, 15}
 };
 
-word8 qt3[2][16] = {
+byte qt3[2][16] = {
 	{13, 7, 15, 4, 1, 2, 6, 14, 9, 11, 3, 0, 8, 5, 12, 10},
 	{11, 9, 5, 1, 12, 3, 13, 14, 6, 4, 7, 15, 2, 0, 8, 10}
 };
 
-word8 qp(const word32 n, const word8 x)
+byte qp(const word32 n, const byte x)
 {
-	word8 a0, a1, a2, a3, a4, b0, b1, b2, b3, b4;
+	byte a0, a1, a2, a3, a4, b0, b1, b2, b3, b4;
 
 	a0 = x >> 4;
 	b0 = x & 15;
@@ -131,8 +131,8 @@ void gen_qtab(TWI * pkey)
 	word32 i;
 
 	for (i = 0; i < 256; ++i) {
-		q(0, i) = qp(0, (word8) i);
-		q(1, i) = qp(1, (word8) i);
+		q(0, i) = qp(0, (byte) i);
+		q(1, i) = qp(1, (byte) i);
 	}
 }
 
@@ -283,12 +283,12 @@ word32 h_fun(TWI * pkey, const word32 x, const word32 key[])
 void gen_mk_tab(TWI * pkey, word32 key[])
 {
 	word32 i;
-	word8 by;
+	byte by;
 
 	switch (pkey->k_len) {
 	case 2:
 		for (i = 0; i < 256; ++i) {
-			by = (word8) i;
+			by = (byte) i;
 #ifdef ONE_STEP
 			pkey->mk_tab[0][i] = mds(0, q20(by));
 			pkey->mk_tab[1][i] = mds(1, q21(by));
@@ -305,7 +305,7 @@ void gen_mk_tab(TWI * pkey, word32 key[])
 
 	case 3:
 		for (i = 0; i < 256; ++i) {
-			by = (word8) i;
+			by = (byte) i;
 #ifdef ONE_STEP
 			pkey->mk_tab[0][i] = mds(0, q30(by));
 			pkey->mk_tab[1][i] = mds(1, q31(by));
@@ -322,7 +322,7 @@ void gen_mk_tab(TWI * pkey, word32 key[])
 
 	case 4:
 		for (i = 0; i < 256; ++i) {
-			by = (word8) i;
+			by = (byte) i;
 #ifdef ONE_STEP
 			pkey->mk_tab[0][i] = mds(0, q40(by));
 			pkey->mk_tab[1][i] = mds(1, q41(by));
@@ -421,7 +421,7 @@ word32 mds_rem(word32 p0, word32 p1)
 
 /* initialise the key schedule from the user supplied key   */
 WIN32DLL_DEFINE
-void _mcrypt_set_key(TWI * pkey, const word32 in_key[],
+int _mcrypt_set_key(TWI * pkey, const word32 in_key[],
 			     const word32 key_len)
 {
 	word32 i, a, b, me_key[4], mo_key[4];
@@ -471,7 +471,7 @@ void _mcrypt_set_key(TWI * pkey, const word32 in_key[],
 #ifdef MK_TABLE
 	gen_mk_tab(pkey, pkey->s_key);
 #endif
-
+return 0;
 }
 
 /* encrypt a block of text  */
