@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1998,1999,2000 Nikos Mavroyanopoulos
+ * Copyright (C) 1998,1999,2000,2001 Nikos Mavroyanopoulos
  * 
  * This library is free software; you can redistribute it and/or modify it 
  * under the terms of the GNU Library General Public License as published 
@@ -50,8 +50,13 @@ int _init_mcrypt( CBC_BUFFER* buf,void *key, int lenofkey, void *IV, int size)
 	buf->previous_ciphertext = malloc( size);
 	buf->previous_plaintext = malloc( size);
 	buf->previous_cipher = malloc( size);
-	memmove(buf->previous_ciphertext, IV, size);
-	memmove(buf->previous_plaintext, IV, size);
+	if (IV!=NULL) {
+		memmove(buf->previous_ciphertext, IV, size);
+		memmove(buf->previous_plaintext, IV, size);
+	} else {
+	        memset(buf->previous_ciphertext, 0, size);
+	        memset(buf->previous_plaintext, 0, size);
+	}
 
 	return 0;
 }
@@ -95,7 +100,7 @@ int _mcrypt( CBC_BUFFER* buf, void *plaintext, int len, int blocksize, void* ake
 		/* Copy the ciphertext to prev_ciphertext */
 		memmove(buf->previous_ciphertext, plain, blocksize);
 	}
-
+	if (j==0 && len!=0) return -1;
 	return 0;
 }
 
@@ -125,7 +130,7 @@ int _mdecrypt( CBC_BUFFER* buf, void *ciphertext, int len, int blocksize,void* a
 		memmove(buf->previous_plaintext, buf->previous_cipher, blocksize);
 
 	}
-
+	if (j==0 && len!=0) return -1;
 	return 0;
 }
 
@@ -136,6 +141,6 @@ char *_mcrypt_get_modes_name() { char*x; x=malloc(10); strcpy(x, "CBC"); return
 int _mcrypt_mode_get_size () {return sizeof(CBC_BUFFER);}
 
 word32 _mcrypt_mode_version() {
-	return 20000331;
+	return 20010201;
 }
 
